declare module 'cpp'{
    namespace Cpp {
        export interface Payment{
            /**
             * Success status of the payment transaction
             */
            success: boolean;

            /**
             * 
             */
            txn?: Payment.Txn | null;
        }

        export namespace Payment{
            export interface Txn{
                /**
                 * Transaction id returned from the payment provider
                 */
                txnId: string;

                /**
                 * Imply transaction is authorised or not
                 */
                authorized: boolean;

                /**
                 * Transaction result code. Note: 00 - Approved/Authorized.
                 */
                resultCode: string;

                /**
                 * Transaction result text.
                 */
                resultText: string;

                /**
                 * Authorization code.
                 */
                authorizationCode: string;

                /**
                 * Timestamp when the transaction was made
                 */
                txnTimestamp: string;

                /**
                 * 
                 */
                 paymentMethod: PaymentMethod.Details
            }
        }

        export interface PaymentCreateParams {
            /**
             * Payment method id returned from Get Customer Payment Method(s) request.
             */
            token: string;
      
            /**
             * Customer id generated from the Create Customer request.
             */
            customerId?: string;

            /**
             * Transaction reference set by API caller
             */
            clientRef: string;

            /**
             * Transaction types include: purchase, auth, validate
             */
            txnType: string;

            /**
             * ISO 4217 3 letter currency code
             */
            currencyCode: string;

            /**
             * Amount for payment
             */
            totalAmount: string;
        }

        export class PaymentsResource {
            /**
             * Creates a new payment object.
             */
            create(
              params?: PaymentCreateParams,
              options?: RequestOptions
            ): Promise<Cpp.Response<Cpp.Payment>>;
            create(
              options?: RequestOptions
            ): Promise<Cpp.Response<Cpp.Payment>>;
        }
    }
}